<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="96"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>DIR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[檔案1、檔案2...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>未知的錯誤回應</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>未知的錯誤回應</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>未知的錯誤回應</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="208"/>
        <source>LXImage-Qt - a simple and fast image viewer

Copyright (C) 2013-2020
LXQt Project: https://lxqt-project.org

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Open File</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Image files (%1)</source>
        <translation>影像檔案 (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Open directory</source>
        <translation>打開資料夾</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Save File</source>
        <translation>儲存檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (讀取中...) - 看圖軟體</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (讀取失敗) - 看圖軟體</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="703"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - 看圖軟體</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>[*]Image Viewer</source>
        <translation>[*]看圖軟體</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1178"/>
        <source>Thumbnails</source>
        <translation>縮圖</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1228"/>
        <source>EXIF Data</source>
        <translation>EXIF資訊</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>清除(&amp;C)</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="293"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="310"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>圖片檢視程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Annotations Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>&amp;Save</source>
        <translation>儲存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Save &amp;As</source>
        <translation>另存新檔(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Zoom &amp;In</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Zoom &amp;Out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>複製到剪貼簿(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Next File</source>
        <translation>下一個檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <location filename="../mainwindow.ui" line="328"/>
        <source>Previous File</source>
        <translation>前一個檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>最近開啟的檔案(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>&amp;Open…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Reload File</source>
        <translation>重新載入檔案(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Original Size</source>
        <translation>原始尺寸</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>&amp;Fit</source>
        <translation>適合視窗大小(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>順時鐘旋轉(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>逆時針旋轉(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>P&amp;references</source>
        <translation>偏好設定(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>&amp;Print</source>
        <translation>列印(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>First File</source>
        <translation>第一個檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Last File</source>
        <translation>最後一個檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>&amp;New Window</source>
        <translation>新視窗(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Flip &amp;Horizontally</source>
        <translation>水平翻轉(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Capture Screenshot</source>
        <translation>拍攝螢幕快照</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>F&amp;ull Screen</source>
        <translation>全螢幕(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Flip &amp;Vertically</source>
        <translation>垂直翻轉(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>從剪貼簿貼上(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>&amp;Slide Show</source>
        <translation>投影片播放(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Show Thumbnails</source>
        <translation>顯示縮圖</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>File Properties</source>
        <translation>檔案屬性</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Open &amp;Directory</source>
        <translation>打開資料夾(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Upload</source>
        <translation>上傳</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>Upload the image</source>
        <translation>上傳影像</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Show EXIF Data</source>
        <translation>顯示EXIF資訊</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="560"/>
        <source>No Tool</source>
        <translation>不使用註解工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Deselect all drawing tools</source>
        <translation>取消選擇所有繪圖工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Draw Arrow</source>
        <translation>畫箭頭</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="578"/>
        <source>Draw an arrow</source>
        <translation>畫一個箭頭</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Draw Rectangle</source>
        <translation>畫矩形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="593"/>
        <source>Draw a hollow rectangle</source>
        <translation>畫一個空心的矩形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Draw Circle</source>
        <translation>畫圓形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>Draw a hollow circle</source>
        <translation>畫一個空心的圓形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Draw Number</source>
        <translation>畫數字</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Draw incrementing numbers</source>
        <translation>畫遞增的數字</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>&amp;Annotations Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="642"/>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Show Outline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="656"/>
        <source>Copy Pa&amp;th</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>Resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>Go</source>
        <translation>前往</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Toolbar</source>
        <translation>工具列</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>偏好設定</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Icon 主題：</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>預設背景顏色:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>全螢幕背景顏色：</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="71"/>
        <source>Maximum number of recent files:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="81"/>
        <source>Slide show interval (seconds):</source>
        <translation>幻燈片放映間隔（秒）:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="95"/>
        <source>Show image outline by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="102"/>
        <source>Show annotations toolbar by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="109"/>
        <source>Fit images when navigating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="117"/>
        <source>Thumbnails</source>
        <translation type="unfinished">縮圖</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="123"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="130"/>
        <source> MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="146"/>
        <source>Show thumbnails dock by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="154"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="173"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="178"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="186"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>Error</source>
        <translation type="unfinished">錯誤</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>螢幕截圖</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>拍攝螢幕截圖</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>區域</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>整個螢幕</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>只有目前的視窗</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>截圖選取的區域</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>包含滑鼠游標</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>延遲:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>包含視窗標題和邊框</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>上傳</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
</context>
</TS>
